Learn R Programming

Crossover (version 0.1-12)

general.carryover: Search for a Cross-Over Design

Description

Search for a Cross-Over Design

Usage

general.carryover(design, model, t0 = 1, rho = 0.5)

Arguments

design
Cross-over design.
model
Model - one of the following numbers or Strings: 1 = "Standard additive model", 2 = "Self-adjacency model", 3 = "Proportionality model", 4 = "Placebo model", 5 = "No carry-over into self model", 6 = "Treatment decay model", 7 = "Full set of interactions",
t0
The number of placebo treatments in the placebo model.
rho
The proportionality parameter for the proportionality model.

Value

  • TODO ...

Details

See the vignette of this package for further details.

References

Jones, B., & Kenward, M. G. (2003). Design and analysis of cross-over trials (Vol. 98). Chapman & Hall.

Examples

Run this code
data(fletcher)
general.carryover(fletcher1, model=1)

Run the code above in your browser using DataLab